use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
50083900
Atria
Chloé
Company
Core
Data
Dates
David
Examples
Fake
Glassdoor
Golden
Internet
Joaquín
José
Kekoa
Names
Ricardo
Signes
Skelton
Stuart
Text
dagolden
declaratively
jjatria
lib
rjbs
stuarts
submodules
